@@ -1,6 +1,6 @@
 /* -- updatedd: updatedd.c --
  *
- * Copyright (C) 2002, 2003, 2004 Philipp Benner
+ * Copyright (C) 2002, 2003, 2004, 2005 Philipp Benner
  *
  * This file is part of UpdateDD - http://updatedd.philipp-benner.de.
  *
@@ -35,6 +35,12 @@
 #include <version.h>
 #include "updatedd.h"
 
+#ifdef __DARWIN__
+#  define PLUGIN_ENDING ".bundle"
+#else
+#  define PLUGIN_ENDING ".so"
+#endif
+
 void
 print_usage(char *pname, FILE *fp)
 {
@@ -59,7 +65,7 @@ print_version(FILE *fp)
 {
 
 	(void)fprintf(fp,
-                      "\n" PNAME " version " VERSION ", Copyright (C) 2004 Philipp Benner.\n"
+                      "\n" PNAME " version " VERSION ", Copyright (C) 2005 Philipp Benner.\n"
                       HOMEPAGE "\n\n"
 
                       "This is free software, and you are welcome to redistribute it\n"
@@ -76,9 +82,10 @@ wrong_usage(const char *msg)
 {
 
 	if(msg != NULL) {
-		fprintf(stderr, "%s\n", msg);
+		(void)fprintf(stderr, "%s\n", msg);
 	}
-	fprintf(stderr, "Try `updatedd --help' for more information.\n");
+	(void)fprintf(stderr,
+		      "Try `updatedd --help' for more information.\n");
 
 	exit(EXIT_FAILURE);
 
@@ -94,7 +101,7 @@ get_libfunc(char *lib, const char *lib_func)
 	char path[256];
 
 	(void)memset(path, 0, sizeof(path));
-	(void)snprintf(path, sizeof(path)-1, "%s/%s.so", LIBPATH, lib);
+	(void)snprintf(path, sizeof(path)-1, "%s/%s" PLUGIN_ENDING, LIBPATH, lib);
 
 	handle = dlopen(path, RTLD_LAZY);
 	if(!handle) {
@@ -121,7 +128,7 @@ get_service(DIR *dir, char *buf, size_t size)
 
 	while( (dir_info = readdir(dir)) ) {
 		int n;
-		char *ptr = strstr(dir_info->d_name, ".so");
+		char *ptr = strstr(dir_info->d_name, PLUGIN_ENDING);
 		if(ptr != NULL) {
 			for(n = 0; dir_info->d_name+n != ptr; n++) {
 				buf[n] = dir_info->d_name[n];
